@@ -1,6 +1,6 @@
-from datetime import date
+from datetime import date, datetime
 from decimal import Decimal
-from typing import Dict, Iterable, NamedTuple, Optional, Tuple
+from typing import Dict, Iterable, Optional, Tuple, Union
 
 
 Index = Tuple[date, Decimal]
@@ -10,3 +10,5 @@ IndexDictionary = Dict[date, Decimal]
 
 IndexesGenerator = Iterable[Index]
 MaybeIndexesGenerator = Iterable[MaybeIndex]
+
+Date = Union[date, datetime, int, float, str]  # parsed by fields.DateField
